[nautilus] window-menus: hide "Close All Windows" when the app menu is showing



commit 3c629b5281bf7c6a02619556855a22b476dbec83
Author: Cosimo Cecchi <cosimoc gnome org>
Date:   Wed Apr 25 13:05:13 2012 -0400

    window-menus: hide "Close All Windows" when the app menu is showing
    
    Since it's the same as our "Quit" option.

 src/nautilus-actions.h      |    1 +
 src/nautilus-window-menus.c |    5 +++--
 2 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/src/nautilus-actions.h b/src/nautilus-actions.h
index d74b9f6..05d45d1 100644
--- a/src/nautilus-actions.h
+++ b/src/nautilus-actions.h
@@ -49,6 +49,7 @@
 #define NAUTILUS_ACTION_ZOOM_NORMAL "Zoom Normal"
 #define NAUTILUS_ACTION_SHOW_HIDDEN_FILES "Show Hidden Files"
 #define NAUTILUS_ACTION_CLOSE "Close"
+#define NAUTILUS_ACTION_CLOSE_ALL_WINDOWS "Close All Windows"
 #define NAUTILUS_ACTION_SEARCH "Search"
 #define NAUTILUS_ACTION_FOLDER_WINDOW "Folder Window"
 #define NAUTILUS_ACTION_NEW_TAB "New Tab"
diff --git a/src/nautilus-window-menus.c b/src/nautilus-window-menus.c
index 24292c5..c2ce9d0 100644
--- a/src/nautilus-window-menus.c
+++ b/src/nautilus-window-menus.c
@@ -905,7 +905,7 @@ static const GtkActionEntry main_entries[] = {
   /* name, stock id, label */  { "New Tab", "tab-new", N_("New _Tab"),
                                  "<control>T", N_("Open another tab for the displayed location"),
                                  G_CALLBACK (action_new_tab_callback) },
   /* name, stock id, label */  { "Close All Windows", NULL, N_("Close _All Windows"),
                                  "<control>Q", N_("Close all Navigation windows"),
                                  G_CALLBACK (action_close_all_windows_callback) },
   /* name, stock id, label */  { NAUTILUS_ACTION_BACK, GTK_STOCK_GO_BACK, N_("_Back"),
@@ -991,7 +991,8 @@ static const gchar* app_actions[] = {
 	NAUTILUS_ACTION_CONNECT_TO_SERVER,
 	NAUTILUS_ACTION_PREFERENCES,
 	NAUTILUS_ACTION_HELP,
-	NAUTILUS_ACTION_ABOUT
+	NAUTILUS_ACTION_ABOUT,
+	NAUTILUS_ACTION_CLOSE_ALL_WINDOWS
 };
 
 GtkActionGroup *
@@ -905,7 +905,7 @@ static const GtkActionEntry main_entries[] = {
                                  "<control>T", N_("Open another tab for the displayed location"),
                                  G_CALLBACK (action_new_tab_callback) },
-  /* name, stock id, label */  { "Close All Windows", NULL, N_("Close _All Windows"),
+  /* name, stock id, label */  { NAUTILUS_ACTION_CLOSE_ALL_WINDOWS, NULL, N_("Close _All Windows"),
                                  "<control>Q", N_("Close all Navigation windows"),
                                  G_CALLBACK (action_close_all_windows_callback) },



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]